@@ -14,6 +14,7 @@ G_BEGIN_DECLS
 #define GDK_WINDOWING_X11
 #endif
 
+#undef GDK_WINDOWING_ANDROID
 #undef GDK_WINDOWING_BROADWAY
 #undef GDK_WINDOWING_MACOS
 
@@ -25,7 +26,7 @@ G_BEGIN_DECLS
 
 #define GDK_RENDERING_CAIRO
 #define GDK_RENDERING_GL
-#define GDK_RENDERING_VULKAN
+#undef GDK_RENDERING_VULKAN
 
 G_END_DECLS
 
